(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{44:function(e,t,a){"use strict";a.r(t);var n=a(9),r=a(6),o=a.n(r),i=a(15),u=a.n(i),s=a(0),l=a(3),c=a(1),d=a(2),m=a(13),p=(a(30),a(21)),v=(a(41),a(42),a(16)),f=a.n(v),g=function(e){Object(c.a)(a,e);var t=Object(d.a)(a);function a(e){var r;return Object(s.a)(this,a),(r=t.call(this,e)).agRef=void 0,r.dtypes=void 0,r.columnTypes={columnTypes:{nonEditableColumn:{editable:!1},editableColumn:{editable:!0},numericRoundedTwoDigitsColumn:{valueFormatter:function(e){return e.value.toFixed(2)}},numericPercentageColumn:{valueFormatter:function(e){return(100*e.value).toFixed(2)+"%"}},numericIntegerColumn:{valueFormatter:function(e){return e.value.toFixed(0)}},shortDateColumn:{filter:"agDateColumnFilter",valueFormatter:function(e){return f.a.utc(e.value).format("DD/MM/YYYY")}},yearMonthDateColumn:{valueFormatter:function(e){return f.a.utc(e.value).format("MMM/YYYY")}}}},r.render=function(){var e=Object.assign({},r.columnTypes,r.parseGridOptions(),{rowData:r.parseGridData()});return Object(n.jsx)("div",{className:"ag-theme-balham",style:{height:400,width:"100%"},children:Object(n.jsx)(p.AgGridReact,{onGridReady:r.onGridReady,onCellValueChanged:function(){return r.onCellChanged()},gridOptions:e,ref:r.agRef})})},r.agRef=o.a.createRef(),r.dtypes=r.props.args.dtypes,r}return Object(l.a)(a,[{key:"parseGridData",value:function(){return JSON.parse(this.props.args.gridData)}},{key:"parseGridOptions",value:function(){return this.props.args.gridOptions}},{key:"onGridReady",value:function(e){e.api.sizeColumnsToFit()}},{key:"onCellChanged",value:function(){var e=this.agRef.current.api,t={dtypes:this.dtypes,csvData:e.getDataAsCsv({allColumns:!0})};m.a.setComponentValue(t)}}]),a}(m.b),h=Object(m.c)(g);u.a.render(Object(n.jsx)(o.a.StrictMode,{children:Object(n.jsx)(h,{})}),document.getElementById("root"))}},[[44,1,2]]]);
//# sourceMappingURL=main.9ef7d638.chunk.js.map